logger

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 10, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package logger provides a super simple way for logging on different levels

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Debug

func Debug(msg string)

Debug writes info logs

func Error

func Error(msg string)

Error writes errors

func Info

func Info(msg string)

Info writes info logs

func SetLogLevel

func SetLogLevel(lvl LogLevel)

SetLogLevel allows consumers to set the logging level

Types

type LogLevel

type LogLevel int

LogLevel is a wrapping type around int to set the loglevel of the package

const (
	// ErrorLevel log level
	ErrorLevel LogLevel = iota
	// InfoLevel log level
	InfoLevel
	// DebugLevel log level
	DebugLevel
)

Jump to