phonydeclared

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 10, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package phonydeclared implements the ruleset for making sure all targets that don't have a rule body are marked PHONY

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Phonydeclared

type Phonydeclared struct{}

Phonydeclared is an empty struct on which to call the rule functions

func (*Phonydeclared) Description

func (r *Phonydeclared) Description(cfg rules.RuleConfig) string

Description returns the description of the rule

func (*Phonydeclared) Name

func (r *Phonydeclared) Name() string

Name returns the name of the rule

func (*Phonydeclared) Run

Run executes the rule logic

Jump to