validator

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 10, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package validator holds the basic engine that runs rule based checks against a Makefile struct

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Validate

func Validate(makefile parser.Makefile, cfg *config.Config) (ret rules.RuleViolationList)

Validate let's you validate a passed in Makefile with the provided config

Types

This section is empty.

Jump to