Documentation
¶
Overview ¶
Package maxbodylength implements the ruleset for making sure target bodies are kept short and thus hopefully somewhat not complex.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MaxBodyLength ¶
type MaxBodyLength struct{}
MaxBodyLength is an empty struct on which to call the rule functions
func (*MaxBodyLength) Description ¶
func (m *MaxBodyLength) Description(cfg rules.RuleConfig) string
Description returns the description of the rule
func (*MaxBodyLength) Name ¶
func (m *MaxBodyLength) Name() string
Name returns the name of the rule
func (*MaxBodyLength) Run ¶
func (m *MaxBodyLength) Run(makefile parser.Makefile, config rules.RuleConfig) rules.RuleViolationList
Run executes the rule logic
Click to show internal directories.
Click to hide internal directories.