Documentation
¶
Overview ¶
Package phonydeclared implements the ruleset for making sure all targets that don't have a rule body are marked PHONY
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Phonydeclared ¶
type Phonydeclared struct{}
Phonydeclared is an empty struct on which to call the rule functions
func (*Phonydeclared) Description ¶
func (r *Phonydeclared) Description(cfg rules.RuleConfig) string
Description returns the description of the rule
func (*Phonydeclared) Name ¶
func (r *Phonydeclared) Name() string
Name returns the name of the rule
func (*Phonydeclared) Run ¶
func (r *Phonydeclared) Run(makefile parser.Makefile, config rules.RuleConfig) rules.RuleViolationList
Run executes the rule logic
Click to show internal directories.
Click to hide internal directories.